@@ -166,7 +166,11 @@ enum StandardAction {
     FullScreen,
     Clear,
     PasteText,
-    SwitchApplicationLanguage
+    SwitchApplicationLanguage,
+    DeleteFile, //< @since 5.25
+    RenameFile, //< @since 5.25
+    MoveToTrash, //< @since 5.25
+    Donate //< @since 5.26
 };
 
 /**
@@ -1061,6 +1065,54 @@ KCONFIGWIDGETS_EXPORT QAction *aboutKDE(const QObject *recvr, const char *slot,
  */
 KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(aboutKDE, AboutKDE)
 
+/**
+ * Delete file.
+ * @since 5.25
+ */
+KCONFIGWIDGETS_EXPORT QAction *deleteFile(const QObject *recvr, const char *slot, QObject *parent);
+
+/**
+ * Delete file.
+ * @since 5.25
+ */
+KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(deleteFile, DeleteFile)
+
+/**
+ * Rename file.
+ * @since 5.25
+ */
+KCONFIGWIDGETS_EXPORT QAction *renameFile(const QObject *recvr, const char *slot, QObject *parent);
+
+/**
+ * Rename file.
+ * @since 5.25
+ */
+KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(renameFile, RenameFile)
+
+/**
+ * Move to Trash.
+ * @since 5.25
+ */
+KCONFIGWIDGETS_EXPORT QAction *moveToTrash(const QObject *recvr, const char *slot, QObject *parent);
+
+/**
+ * Move to Trash.
+ * @since 5.25
+ */
+KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(moveToTrash, MoveToTrash)
+
+/**
+ * Open donation page on kde.org.
+ * @since 5.26
+ */
+KCONFIGWIDGETS_EXPORT QAction *donate(const QObject *recvr, const char *slot, QObject *parent);
+
+/**
+ * Open donation page on kde.org.
+ * @since 5.26
+ */
+KSTANDARDACTION_WITH_NEW_STYLE_CONNECT(donate, Donate)
+
 }
 
 #endif // KSTDACTION_H
